==> bibledit_1.7.orig.tar.gz: bibledit-1.7/src/dialoggotoreference.h <==
/*
** Copyright (C) 2003-2006 Teus Benschop.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGGOTOREFERENCE_H
#define INCLUDED_DIALOGGOTOREFERENCE_H

#include <glib.h>
#include <gtk/gtk.h>
#include "ustring.h"
#include "session.h"
#include "configuration.h"
#include "scripture.h"


class GotoReferenceDialog
{
public:
  GotoReferenceDialog (const ustring& currentbook, const ustring& currentchapter, const ustring& currentverse, Session * session, Configuration * configuration);
  virtual ~GotoReferenceDialog ();
  virtual int run();
  bool newreference;
  ustring newbook;
  ustring newchapter;
  ustring newverse;
protected:
  GtkWidget *gotoreferencedialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *label4;
  GtkWidget *notebook1;
  GtkWidget *hbox1;
  GtkWidget *label1;
  GtkWidget *entry1;
  GtkWidget *label2;
  GtkWidget *table1;
  GtkWidget *label5;
  GtkWidget *label6;
  GtkWidget *label7;
  GtkWidget *scrolledwindow1;
  GtkWidget *treeview1;
  GtkWidget *scrolledwindow2;
  GtkWidget *treeview2;
  GtkWidget *scrolledwindow3;
  GtkWidget *treeview3;
  GtkWidget *label3;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton1;
  GtkWidget *okbutton1;
  GtkAccelGroup *accel_group;
private:
  ustring oldbook;
  ustring oldchapter;
  ustring oldverse;
  Session * mysession;
  Scripture * scripture;
  vector <ustring> input;
  virtual void on_jump();
  static void on_okbutton1_clicked (GtkButton *button, gpointer user_data);
  virtual void show_bad_reference ();
  static void on_gotoreferencedialog_activate_focus (GtkWindow *window, gpointer user_data);
  virtual void on_control_g ();
  static void on_entry1_activate (GtkEntry *entry, gpointer user_data);
  virtual void on_activate ();
  static bool on_timeout (gpointer data);
  virtual void timeout ();
  bool allow_activate;
  GtkListStore *store1;
  GtkListStore *store2;
  GtkListStore *store3;
  GtkTreeViewColumn *column1;
  GtkTreeViewColumn *column2;
  GtkTreeViewColumn *column3;
  GtkTreeSelection *select1;
  GtkTreeSelection *select2;
  GtkTreeSelection *select3;
  static gboolean on_treeview1_move_cursor (GtkTreeView *treeview, GtkMovementStep step, gint count, gpointer user_data);
  static void on_treeview1_row_activated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data);
  static gboolean on_treeview2_move_cursor (GtkTreeView *treeview, GtkMovementStep step, gint count, gpointer user_data);
  static void on_treeview2_row_activated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data);
  static gboolean on_treeview3_move_cursor (GtkTreeView *treeview, GtkMovementStep step, gint count, gpointer user_data);
  static void on_treeview3_row_activated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data);
  virtual void on_move1 ();
  virtual void on_activate1 ();
  virtual void on_move2 ();
  virtual void on_activate2 ();
  virtual void on_move3 ();
  virtual void on_activate3 ();
};


#endif

==> bibledit_1.9.orig.tar.gz: bibledit-1.9/src/dialoggotoreference.h <==
/*
** Copyright (C) 2003-2006 Teus Benschop.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#ifndef INCLUDED_DIALOGGOTOREFERENCE_H
#define INCLUDED_DIALOGGOTOREFERENCE_H


#include <glib.h>
#include <gtk/gtk.h>
#include "ustring.h"
#include "generalconfig.h"


class GotoReferenceDialog
{
public:
  GotoReferenceDialog (const ustring& currentbook, const ustring& currentchapter, const ustring& currentverse);
  ~GotoReferenceDialog ();
  int run();
  bool newreference;
  ustring newbook;
  ustring newchapter;
  ustring newverse;
protected:
  GtkWidget *gotoreferencedialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *label4;
  GtkWidget *notebook1;
  GtkWidget *hbox1;
  GtkWidget *label1;
  GtkWidget *entry1;
  GtkWidget *label2;
  GtkWidget *table1;
  GtkWidget *label5;
  GtkWidget *label6;
  GtkWidget *label7;
  GtkWidget *scrolledwindow1;
  GtkWidget *treeview1;
  GtkWidget *scrolledwindow2;
  GtkWidget *treeview2;
  GtkWidget *scrolledwindow3;
  GtkWidget *treeview3;
  GtkWidget *label3;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton1;
  GtkWidget *okbutton1;
  GtkAccelGroup *accel_group;
private:
  ustring oldbook;
  ustring oldchapter;
  ustring oldverse;
  GeneralConfiguration genconfig;
  vector <ustring> input;
  void on_jump();
  static void on_okbutton1_clicked (GtkButton *button, gpointer user_data);
  void show_bad_reference ();
  static void on_gotoreferencedialog_activate_focus (GtkWindow *window, gpointer user_data);
  void on_control_g ();
  static void on_entry1_activate (GtkEntry *entry, gpointer user_data);
  void on_activate ();
  static bool on_timeout (gpointer data);
  void timeout ();
  bool allow_activate;
  GtkListStore *store1;
  GtkListStore *store2;
  GtkListStore *store3;
  GtkTreeViewColumn *column1;
  GtkTreeViewColumn *column2;
  GtkTreeViewColumn *column3;
  GtkTreeSelection *select1;
  GtkTreeSelection *select2;
  GtkTreeSelection *select3;
  static gboolean on_treeview1_move_cursor (GtkTreeView *treeview, GtkMovementStep step, gint count, gpointer user_data);
  static void on_treeview1_row_activated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data);
  static gboolean on_treeview2_move_cursor (GtkTreeView *treeview, GtkMovementStep step, gint count, gpointer user_data);
  static void on_treeview2_row_activated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data);
  static gboolean on_treeview3_move_cursor (GtkTreeView *treeview, GtkMovementStep step, gint count, gpointer user_data);
  static void on_treeview3_row_activated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data);
  void on_move1 ();
  void on_activate1 ();
  void on_move2 ();
  void on_activate2 ();
  void on_move3 ();
  void on_activate3 ();
};


#endif
